# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['google_photos_archiver']

package_data = \
{'': ['*']}

install_requires = \
['click==7.1.2', 'google-auth-oauthlib>=0.4.2,<0.5.0', 'requests==2.25.1']

entry_points = \
{'console_scripts': ['google-photos-archiver = google_photos_archiver.cli:cli']}

setup_kwargs = {
    'name': 'google-photos-archiver',
    'version': '0.1.6',
    'description': 'Archives the contents of your Google Photos library to disk',
    'long_description': '# google-photos-archiver\n[![CircleCI](https://circleci.com/gh/scottx611x/google-photos-archiver.svg?style=svg&circle-token=54dbe16b5fd34bb8c3a646a479b75f640e1c18b5)](https://circleci.com/gh/scottx611x/google-photos-archiver/tree/main)\n[![codecov](https://codecov.io/gh/scottx611x/google-photos-archiver/branch/main/graph/badge.svg?token=KGmF8LIaY4)](https://codecov.io/gh/scottx611x/google-photos-archiver)\n\n* [What?](#what)\n* [Why?](#why)\n* [How?](#how)\n* [Pre\\-reqs](#pre-reqs)\n  * [Development Reqs](#development-reqs)\n* [Getting Started](#getting-started)\n  * [Google Oauth Setup](#google-oauth-setup)\n  * [First Run](#first-run)\n  * [Usage](#usage)\n  * [\\.\\.\\. with Docker](#-with-docker)\n  * [Running tests](#running-tests)\n* [Examples](#examples)\n  * [Specify a different download location](#specify-a-different-download-location)\n  * [Download from specific dates (with wildcard support)](#download-from-specific-dates-with-wildcard-support)\n  * [\\-\\-help](#--help)\n  * [archive\\-media\\-items \\-\\-help](#archive-media-items---help)\n  * [Download Path Hierarchy](#download-path-hierarchy)\n\n[comment]: <> (Created with https://github.com/ekalinin/github-markdown-toc.go)\n[comment]: <> (brew install github-markdown-toc && cat ./README.md | gh-md-toc)\n\n## What?\n`google-photos-archiver` aims to provide a simple, fast, extensible interface to be able to back up one\'s Google Photos to a location of their choosing.\n\nI\'ve drawn inspiration from projects such as: https://github.com/mholt/timeliner & https://github.com/gilesknap/gphotos-sync but wanted to cut my teeth in this domain and see what I could come up with myself.\n\n## Why?\n\nI wanted a tool (of my own creation) which could easily provide a copy of mine and my partner\'s Google Photos libraries, and keep said copy up to date over time.\n\nIn reality I\'ve mainly just needed a distraction from the vicious cycle of wake, work, Netflix, sleep, and I thought it was high time to do a little side project.\n\n## How?\n\n### Pre-reqs\n\n- `docker`\n\n... Or\n\n- `python==3.8`\n- [poetry](https://python-poetry.org/docs/#installation) `>=1.0.0`\n\n#### Development Reqs\n- [pre-commit](https://pre-commit.com/#install)\n  - Run `pre-commit install`\n\n### Getting Started\n\n#### Google Oauth Setup\nThese instructions will help you set up Google OAuth2 client credentials so you can start using `google-photos-archiver`\n\n- While logged into your Google account navigate to [Create a New Project](https://console.developers.google.com/projectcreate)\n- Create one, and switch to using it with the UI dropdown\n- Navigate to `APIs & Services` click on `+ Enable APIs and services`, and enable the `Photos Library API`\n- Navigate back to `APIs & Services` and click on `Credentials`\n- Click on `+ Create Credentials > OAuth client ID`\n- Configure an OAuth consent screen. You can just fill out the required fields and hit Save.\n  - Click `Add Or Remove Scopes` and manually add scope: `https://www.googleapis.com/auth/photoslibrary.readonly`\n  - Accept remaining defaults, save through and return to `Credentials`\n- Click on `+ Create Credentials > OAuth client ID`\n- Make a `"Desktop App"`\n- Congrats!, you now have a Client ID and Client Secret\n- Download the associated `client_secret.json` file and make note of its location as we\'ll be providing it\'s path to `google-photos-archiver`\n\n#### First Run\nA browser window will be opened during the initial OAuth flow. After successfully authenticating once, a refresh token will be stored for future use (See: `--refresh-token-path`) and will omit the need to reauthenticate.\n\n#### Usage\n```\n$ git clone git@github.com:scottx611x/google-photos-archiver.git\n$ poetry install\n$ poetry run google-photos-archiver --help\n```\n\n#### ... with Docker\n\n> Note that some more Docker volume mounting will be warranted here if you want to specify a different path to download to etc.\n> Ref: https://docs.docker.com/storage/volumes\n\n```\n$ docker build . -t google-photos-archiver\n$ docker run -v $PWD:/app/ google-photos-archiver  --help\n```\n\n#### Running tests\n```\n$ poetry run pytest\n```\n\n### Examples\n\n#### Specify a different download location\n```\n$ poetry run google-photos-archiver archive-media-items --download-path /Volumes/my-big-hdd/downloaded_media\n```\n\n#### Download from specific dates (with wildcard support)\n```\n$ poetry run google-photos-archiver archive-media-items --date-filter 2020/*/*,2021/8/22\n$ poetry run google-photos-archiver archive-media-items --date-range-filter 2019/8/22-2020/8/22\n```\n\n#### `--help`\n```\nUsage: google-photos-archiver [OPTIONS] COMMAND [ARGS]...\n\nOptions:\n  --client-secret-json-path TEXT  `client_secret.json` file acquired from http\n                                  s://developers.google.com/photos/library/gui\n                                  des/get-started#request-id  [default:\n                                  ./client_secret.json; required]\n\n  --refresh-token-path TEXT       [default: ./refresh_token]\n  --help                          Show this message and exit.\n\nCommands:\n  archive-media-items\n```\n\n#### `archive-media-items --help`\n```\nUsage: google-photos-archiver archive-media-items [OPTIONS]\n\nOptions:\n  --download-path TEXT            Directory that MediaItems will be archived\n                                  to  [default: ./downloaded_media]\n\n  --sqlite-db-path TEXT           [default: ./media_items.db]\n  --max-threadpool-workers INTEGER\n                                  The maximum amount of workers to utilize for\n                                  the ThreadPoolExecutor  [default: 100]\n\n  --max-media-items INTEGER       The maximum amount of MediaItems to account\n                                  for and archive in a given execution\n                                  [default: 200]\n\n  --date-filter TEXT              Up to 5 comma delimited Dates conforming to\n                                  the YYYY/MM/DD pattern. Any of YYYY/MM/DD\n                                  can be wildcarded (*) like so:\n                                  */MM/DD,YYYY/*/DD,YYYY/MM/*\n\n  --date-range-filter TEXT        Up to 5 comma delimited DateRanges\n                                  conforming to the YYYY/MM/DD-YYYY/MM/DD\n                                  (<start_date>-<end_date>) pattern.\n\n  --help                          Show this message and exit.\n```\n\n#### Download Path Hierarchy\n```\n$ tree /<download_path>/downloaded_media/ | head\n/Volumes/2TB/google-photos/scott/downloaded_media/\n├── 2021\n│ └── 1\n│     ├── 1\n│     │ └── a.jpg\n│     └── 2\n│         └── b.mov\n├── 2020\n│ ├── 1\n│ │ └── 2\n│ │     └── c.jpg\n│ └── 2\n│     └── 3\n│         └── d.jpg\n...\n```\n',
    'author': 'Scott Ouellette',
    'author_email': 'scottx611x@gmail.com',
    'maintainer': 'Scott Ouellette',
    'maintainer_email': 'scottx611x@gmail.com',
    'url': 'https://github.com/scottx611x/google-photos-archiver',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8.0,<4.0.0',
}


setup(**setup_kwargs)
